# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ledger/rwset/rwset.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18ledger/rwset/rwset.proto\x12\x05rwset\"\x83\x01\n\x0eTxReadWriteSet\x12\x33\n\ndata_model\x18\x01 \x01(\x0e\x32\x1f.rwset.TxReadWriteSet.DataModel\x12\'\n\x08ns_rwset\x18\x02 \x03(\x0b\x32\x15.rwset.NsReadWriteSet\"\x13\n\tDataModel\x12\x06\n\x02KV\x10\x00\"x\n\x0eNsReadWriteSet\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\r\n\x05rwset\x18\x02 \x01(\x0c\x12\x44\n\x17\x63ollection_hashed_rwset\x18\x03 \x03(\x0b\x32#.rwset.CollectionHashedReadWriteSet\"e\n\x1c\x43ollectionHashedReadWriteSet\x12\x17\n\x0f\x63ollection_name\x18\x01 \x01(\t\x12\x14\n\x0chashed_rwset\x18\x02 \x01(\x0c\x12\x16\n\x0epvt_rwset_hash\x18\x03 \x01(\x0c\"x\n\x11TxPvtReadWriteSet\x12\x33\n\ndata_model\x18\x01 \x01(\x0e\x32\x1f.rwset.TxReadWriteSet.DataModel\x12.\n\x0cns_pvt_rwset\x18\x02 \x03(\x0b\x32\x18.rwset.NsPvtReadWriteSet\"f\n\x11NsPvtReadWriteSet\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12>\n\x14\x63ollection_pvt_rwset\x18\x02 \x03(\x0b\x32 .rwset.CollectionPvtReadWriteSet\"C\n\x19\x43ollectionPvtReadWriteSet\x12\x17\n\x0f\x63ollection_name\x18\x01 \x01(\t\x12\r\n\x05rwset\x18\x02 \x01(\x0c\x42\x62\n*org.hyperledger.fabric.protos.ledger.rwsetZ4github.com/hyperledger/fabric-protos-go/ledger/rwsetb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ledger.rwset.rwset_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n*org.hyperledger.fabric.protos.ledger.rwsetZ4github.com/hyperledger/fabric-protos-go/ledger/rwset'
  _TXREADWRITESET._serialized_start=36
  _TXREADWRITESET._serialized_end=167
  _TXREADWRITESET_DATAMODEL._serialized_start=148
  _TXREADWRITESET_DATAMODEL._serialized_end=167
  _NSREADWRITESET._serialized_start=169
  _NSREADWRITESET._serialized_end=289
  _COLLECTIONHASHEDREADWRITESET._serialized_start=291
  _COLLECTIONHASHEDREADWRITESET._serialized_end=392
  _TXPVTREADWRITESET._serialized_start=394
  _TXPVTREADWRITESET._serialized_end=514
  _NSPVTREADWRITESET._serialized_start=516
  _NSPVTREADWRITESET._serialized_end=618
  _COLLECTIONPVTREADWRITESET._serialized_start=620
  _COLLECTIONPVTREADWRITESET._serialized_end=687
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: common/ledger.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x13\x63ommon/ledger.proto\x12\x06\x63ommon\"\x9b\x01\n\x0e\x42lockchainInfo\x12\x0e\n\x06height\x18\x01 \x01(\x04\x12\x18\n\x10\x63urrentBlockHash\x18\x02 \x01(\x0c\x12\x19\n\x11previousBlockHash\x18\x03 \x01(\x0c\x12\x44\n\x19\x62ootstrappingSnapshotInfo\x18\x04 \x01(\x0b\x32!.common.BootstrappingSnapshotInfo\"8\n\x19\x42ootstrappingSnapshotInfo\x12\x1b\n\x13lastBlockInSnapshot\x18\x01 \x01(\x04\x42V\n$org.hyperledger.fabric.protos.commonZ.github.com/hyperledger/fabric-protos-go/commonb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'common.ledger_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n$org.hyperledger.fabric.protos.commonZ.github.com/hyperledger/fabric-protos-go/common'
  _BLOCKCHAININFO._serialized_start=32
  _BLOCKCHAININFO._serialized_end=187
  _BOOTSTRAPPINGSNAPSHOTINFO._serialized_start=189
  _BOOTSTRAPPINGSNAPSHOTINFO._serialized_end=245
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: orderer/kafka.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x13orderer/kafka.proto\x12\x07orderer\"\xaf\x01\n\x0cKafkaMessage\x12/\n\x07regular\x18\x01 \x01(\x0b\x32\x1c.orderer.KafkaMessageRegularH\x00\x12\x35\n\x0btime_to_cut\x18\x02 \x01(\x0b\x32\x1e.orderer.KafkaMessageTimeToCutH\x00\x12/\n\x07\x63onnect\x18\x03 \x01(\x0b\x32\x1c.orderer.KafkaMessageConnectH\x00\x42\x06\n\x04Type\"\xb4\x01\n\x13KafkaMessageRegular\x12\x0f\n\x07payload\x18\x01 \x01(\x0c\x12\x12\n\nconfig_seq\x18\x02 \x01(\x04\x12\x31\n\x05\x63lass\x18\x03 \x01(\x0e\x32\".orderer.KafkaMessageRegular.Class\x12\x17\n\x0foriginal_offset\x18\x04 \x01(\x03\",\n\x05\x43lass\x12\x0b\n\x07UNKNOWN\x10\x00\x12\n\n\x06NORMAL\x10\x01\x12\n\n\x06\x43ONFIG\x10\x02\"-\n\x15KafkaMessageTimeToCut\x12\x14\n\x0c\x62lock_number\x18\x01 \x01(\x04\"&\n\x13KafkaMessageConnect\x12\x0f\n\x07payload\x18\x01 \x01(\x0c\"~\n\rKafkaMetadata\x12\x1d\n\x15last_offset_persisted\x18\x01 \x01(\x03\x12&\n\x1elast_original_offset_processed\x18\x02 \x01(\x03\x12&\n\x1elast_resubmitted_config_offset\x18\x03 \x01(\x03\x42X\n%org.hyperledger.fabric.protos.ordererZ/github.com/hyperledger/fabric-protos-go/ordererb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'orderer.kafka_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n%org.hyperledger.fabric.protos.ordererZ/github.com/hyperledger/fabric-protos-go/orderer'
  _KAFKAMESSAGE._serialized_start=33
  _KAFKAMESSAGE._serialized_end=208
  _KAFKAMESSAGEREGULAR._serialized_start=211
  _KAFKAMESSAGEREGULAR._serialized_end=391
  _KAFKAMESSAGEREGULAR_CLASS._serialized_start=347
  _KAFKAMESSAGEREGULAR_CLASS._serialized_end=391
  _KAFKAMESSAGETIMETOCUT._serialized_start=393
  _KAFKAMESSAGETIMETOCUT._serialized_end=438
  _KAFKAMESSAGECONNECT._serialized_start=440
  _KAFKAMESSAGECONNECT._serialized_end=478
  _KAFKAMETADATA._serialized_start=480
  _KAFKAMETADATA._serialized_end=606
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from fabric_protos_python.common import common_pb2 as common_dot_common__pb2
from fabric_protos_python.orderer import ab_pb2 as orderer_dot_ab__pb2


class AtomicBroadcastStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Broadcast = channel.stream_stream(
                '/orderer.AtomicBroadcast/Broadcast',
                request_serializer=common_dot_common__pb2.Envelope.SerializeToString,
                response_deserializer=orderer_dot_ab__pb2.BroadcastResponse.FromString,
                )
        self.Deliver = channel.stream_stream(
                '/orderer.AtomicBroadcast/Deliver',
                request_serializer=common_dot_common__pb2.Envelope.SerializeToString,
                response_deserializer=orderer_dot_ab__pb2.DeliverResponse.FromString,
                )


class AtomicBroadcastServicer(object):
    """Missing associated documentation comment in .proto file."""

    def Broadcast(self, request_iterator, context):
        """broadcast receives a reply of Acknowledgement for each common.Envelope in order, indicating success or type of failure
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Deliver(self, request_iterator, context):
        """deliver first requires an Envelope of type DELIVER_SEEK_INFO with Payload data as a mashaled SeekInfo message, then a stream of block replies is received.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_AtomicBroadcastServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Broadcast': grpc.stream_stream_rpc_method_handler(
                    servicer.Broadcast,
                    request_deserializer=common_dot_common__pb2.Envelope.FromString,
                    response_serializer=orderer_dot_ab__pb2.BroadcastResponse.SerializeToString,
            ),
            'Deliver': grpc.stream_stream_rpc_method_handler(
                    servicer.Deliver,
                    request_deserializer=common_dot_common__pb2.Envelope.FromString,
                    response_serializer=orderer_dot_ab__pb2.DeliverResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'orderer.AtomicBroadcast', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class AtomicBroadcast(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def Broadcast(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_stream(request_iterator, target, '/orderer.AtomicBroadcast/Broadcast',
            common_dot_common__pb2.Envelope.SerializeToString,
            orderer_dot_ab__pb2.BroadcastResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Deliver(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_stream(request_iterator, target, '/orderer.AtomicBroadcast/Deliver',
            common_dot_common__pb2.Envelope.SerializeToString,
            orderer_dot_ab__pb2.DeliverResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: peer/signed_cc_dep_spec.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from fabric_protos_python.peer import proposal_response_pb2 as peer_dot_proposal__response__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1dpeer/signed_cc_dep_spec.proto\x12\x06protos\x1a\x1cpeer/proposal_response.proto\"\x91\x01\n\x1dSignedChaincodeDeploymentSpec\x12!\n\x19\x63haincode_deployment_spec\x18\x01 \x01(\x0c\x12\x1c\n\x14instantiation_policy\x18\x02 \x01(\x0c\x12/\n\x12owner_endorsements\x18\x03 \x03(\x0b\x32\x13.protos.EndorsementBR\n\"org.hyperledger.fabric.protos.peerZ,github.com/hyperledger/fabric-protos-go/peerb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'peer.signed_cc_dep_spec_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\"org.hyperledger.fabric.protos.peerZ,github.com/hyperledger/fabric-protos-go/peer'
  _SIGNEDCHAINCODEDEPLOYMENTSPEC._serialized_start=72
  _SIGNEDCHAINCODEDEPLOYMENTSPEC._serialized_end=217
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: common/policies.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from fabric_protos_python.msp import msp_principal_pb2 as msp_dot_msp__principal__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15\x63ommon/policies.proto\x12\x06\x63ommon\x1a\x17msp/msp_principal.proto\"k\n\x06Policy\x12\x0c\n\x04type\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x01(\x0c\"D\n\nPolicyType\x12\x0b\n\x07UNKNOWN\x10\x00\x12\r\n\tSIGNATURE\x10\x01\x12\x07\n\x03MSP\x10\x02\x12\x11\n\rIMPLICIT_META\x10\x03\"{\n\x17SignaturePolicyEnvelope\x12\x0f\n\x07version\x18\x01 \x01(\x05\x12%\n\x04rule\x18\x02 \x01(\x0b\x32\x17.common.SignaturePolicy\x12(\n\nidentities\x18\x03 \x03(\x0b\x32\x14.common.MSPPrincipal\"\x9f\x01\n\x0fSignaturePolicy\x12\x13\n\tsigned_by\x18\x01 \x01(\x05H\x00\x12\x32\n\x08n_out_of\x18\x02 \x01(\x0b\x32\x1e.common.SignaturePolicy.NOutOfH\x00\x1a;\n\x06NOutOf\x12\t\n\x01n\x18\x01 \x01(\x05\x12&\n\x05rules\x18\x02 \x03(\x0b\x32\x17.common.SignaturePolicyB\x06\n\x04Type\"\x7f\n\x12ImplicitMetaPolicy\x12\x12\n\nsub_policy\x18\x01 \x01(\t\x12-\n\x04rule\x18\x02 \x01(\x0e\x32\x1f.common.ImplicitMetaPolicy.Rule\"&\n\x04Rule\x12\x07\n\x03\x41NY\x10\x00\x12\x07\n\x03\x41LL\x10\x01\x12\x0c\n\x08MAJORITY\x10\x02\"\x87\x01\n\x11\x41pplicationPolicy\x12;\n\x10signature_policy\x18\x01 \x01(\x0b\x32\x1f.common.SignaturePolicyEnvelopeH\x00\x12)\n\x1f\x63hannel_config_policy_reference\x18\x02 \x01(\tH\x00:\x02\x18\x01\x42\x06\n\x04TypeBV\n$org.hyperledger.fabric.protos.commonZ.github.com/hyperledger/fabric-protos-go/commonb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'common.policies_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n$org.hyperledger.fabric.protos.commonZ.github.com/hyperledger/fabric-protos-go/common'
  _APPLICATIONPOLICY._options = None
  _APPLICATIONPOLICY._serialized_options = b'\030\001'
  _POLICY._serialized_start=58
  _POLICY._serialized_end=165
  _POLICY_POLICYTYPE._serialized_start=97
  _POLICY_POLICYTYPE._serialized_end=165
  _SIGNATUREPOLICYENVELOPE._serialized_start=167
  _SIGNATUREPOLICYENVELOPE._serialized_end=290
  _SIGNATUREPOLICY._serialized_start=293
  _SIGNATUREPOLICY._serialized_end=452
  _SIGNATUREPOLICY_NOUTOF._serialized_start=385
  _SIGNATUREPOLICY_NOUTOF._serialized_end=444
  _IMPLICITMETAPOLICY._serialized_start=454
  _IMPLICITMETAPOLICY._serialized_end=581
  _IMPLICITMETAPOLICY_RULE._serialized_start=543
  _IMPLICITMETAPOLICY_RULE._serialized_end=581
  _APPLICATIONPOLICY._serialized_start=584
  _APPLICATIONPOLICY._serialized_end=719
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: transientstore/transientstore.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from fabric_protos_python.ledger.rwset import rwset_pb2 as ledger_dot_rwset_dot_rwset__pb2
from fabric_protos_python.peer import collection_pb2 as peer_dot_collection__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#transientstore/transientstore.proto\x12\x0etransientstore\x1a\x18ledger/rwset/rwset.proto\x1a\x15peer/collection.proto\"\xa2\x02\n\x1fTxPvtReadWriteSetWithConfigInfo\x12\x13\n\x0b\x65ndorsed_at\x18\x01 \x01(\x04\x12+\n\tpvt_rwset\x18\x02 \x01(\x0b\x32\x18.rwset.TxPvtReadWriteSet\x12\x62\n\x12\x63ollection_configs\x18\x03 \x03(\x0b\x32\x46.transientstore.TxPvtReadWriteSetWithConfigInfo.CollectionConfigsEntry\x1aY\n\x16\x43ollectionConfigsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12.\n\x05value\x18\x02 \x01(\x0b\x32\x1f.protos.CollectionConfigPackage:\x02\x38\x01\x42\x66\n,org.hyperledger.fabric.protos.transientstoreZ6github.com/hyperledger/fabric-protos-go/transientstoreb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'transientstore.transientstore_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n,org.hyperledger.fabric.protos.transientstoreZ6github.com/hyperledger/fabric-protos-go/transientstore'
  _TXPVTREADWRITESETWITHCONFIGINFO_COLLECTIONCONFIGSENTRY._options = None
  _TXPVTREADWRITESETWITHCONFIGINFO_COLLECTIONCONFIGSENTRY._serialized_options = b'8\001'
  _TXPVTREADWRITESETWITHCONFIGINFO._serialized_start=105
  _TXPVTREADWRITESETWITHCONFIGINFO._serialized_end=395
  _TXPVTREADWRITESETWITHCONFIGINFO_COLLECTIONCONFIGSENTRY._serialized_start=306
  _TXPVTREADWRITESETWITHCONFIGINFO_COLLECTIONCONFIGSENTRY._serialized_end=395
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from fabric_protos_python.peer import snapshot_pb2 as peer_dot_snapshot__pb2


class SnapshotStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Generate = channel.unary_unary(
                '/protos.Snapshot/Generate',
                request_serializer=peer_dot_snapshot__pb2.SignedSnapshotRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.Cancel = channel.unary_unary(
                '/protos.Snapshot/Cancel',
                request_serializer=peer_dot_snapshot__pb2.SignedSnapshotRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.QueryPendings = channel.unary_unary(
                '/protos.Snapshot/QueryPendings',
                request_serializer=peer_dot_snapshot__pb2.SignedSnapshotRequest.SerializeToString,
                response_deserializer=peer_dot_snapshot__pb2.QueryPendingSnapshotsResponse.FromString,
                )


class SnapshotServicer(object):
    """Missing associated documentation comment in .proto file."""

    def Generate(self, request, context):
        """Generate a snapshot reqeust. SignedSnapshotRequest contains marshalled bytes for SnaphostRequest
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Cancel(self, request, context):
        """Cancel a snapshot reqeust. SignedSnapshotRequest contains marshalled bytes for SnaphostRequest
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def QueryPendings(self, request, context):
        """Query pending snapshots query. SignedSnapshotRequest contains marshalled bytes for SnaphostQuery
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_SnapshotServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Generate': grpc.unary_unary_rpc_method_handler(
                    servicer.Generate,
                    request_deserializer=peer_dot_snapshot__pb2.SignedSnapshotRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'Cancel': grpc.unary_unary_rpc_method_handler(
                    servicer.Cancel,
                    request_deserializer=peer_dot_snapshot__pb2.SignedSnapshotRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'QueryPendings': grpc.unary_unary_rpc_method_handler(
                    servicer.QueryPendings,
                    request_deserializer=peer_dot_snapshot__pb2.SignedSnapshotRequest.FromString,
                    response_serializer=peer_dot_snapshot__pb2.QueryPendingSnapshotsResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'protos.Snapshot', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Snapshot(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def Generate(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.Snapshot/Generate',
            peer_dot_snapshot__pb2.SignedSnapshotRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Cancel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.Snapshot/Cancel',
            peer_dot_snapshot__pb2.SignedSnapshotRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def QueryPendings(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.Snapshot/QueryPendings',
            peer_dot_snapshot__pb2.SignedSnapshotRequest.SerializeToString,
            peer_dot_snapshot__pb2.QueryPendingSnapshotsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: orderer/etcdraft/metadata.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1forderer/etcdraft/metadata.proto\x12\x08\x65tcdraft\"U\n\rBlockMetadata\x12\x15\n\rconsenter_ids\x18\x01 \x03(\x04\x12\x19\n\x11next_consenter_id\x18\x02 \x01(\x04\x12\x12\n\nraft_index\x18\x03 \x01(\x04\"\'\n\x0f\x43lusterMetadata\x12\x14\n\x0c\x61\x63tive_nodes\x18\x01 \x03(\x04\x42j\n.org.hyperledger.fabric.protos.orderer.etcdraftZ8github.com/hyperledger/fabric-protos-go/orderer/etcdraftb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'orderer.etcdraft.metadata_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n.org.hyperledger.fabric.protos.orderer.etcdraftZ8github.com/hyperledger/fabric-protos-go/orderer/etcdraft'
  _BLOCKMETADATA._serialized_start=45
  _BLOCKMETADATA._serialized_end=130
  _CLUSTERMETADATA._serialized_start=132
  _CLUSTERMETADATA._serialized_end=171
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ledger/rwset/kvrwset/kv_rwset.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#ledger/rwset/kvrwset/kv_rwset.proto\x12\x07kvrwset\"\xb3\x01\n\x07KVRWSet\x12\x1e\n\x05reads\x18\x01 \x03(\x0b\x32\x0f.kvrwset.KVRead\x12\x33\n\x12range_queries_info\x18\x02 \x03(\x0b\x32\x17.kvrwset.RangeQueryInfo\x12 \n\x06writes\x18\x03 \x03(\x0b\x32\x10.kvrwset.KVWrite\x12\x31\n\x0fmetadata_writes\x18\x04 \x03(\x0b\x32\x18.kvrwset.KVMetadataWrite\"\x9c\x01\n\x0bHashedRWSet\x12)\n\x0chashed_reads\x18\x01 \x03(\x0b\x32\x13.kvrwset.KVReadHash\x12+\n\rhashed_writes\x18\x02 \x03(\x0b\x32\x14.kvrwset.KVWriteHash\x12\x35\n\x0fmetadata_writes\x18\x03 \x03(\x0b\x32\x1c.kvrwset.KVMetadataWriteHash\"8\n\x06KVRead\x12\x0b\n\x03key\x18\x01 \x01(\t\x12!\n\x07version\x18\x02 \x01(\x0b\x32\x10.kvrwset.Version\"8\n\x07KVWrite\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x11\n\tis_delete\x18\x02 \x01(\x08\x12\r\n\x05value\x18\x03 \x01(\x0c\"I\n\x0fKVMetadataWrite\x12\x0b\n\x03key\x18\x01 \x01(\t\x12)\n\x07\x65ntries\x18\x02 \x03(\x0b\x32\x18.kvrwset.KVMetadataEntry\"A\n\nKVReadHash\x12\x10\n\x08key_hash\x18\x01 \x01(\x0c\x12!\n\x07version\x18\x02 \x01(\x0b\x32\x10.kvrwset.Version\"F\n\x0bKVWriteHash\x12\x10\n\x08key_hash\x18\x01 \x01(\x0c\x12\x11\n\tis_delete\x18\x02 \x01(\x08\x12\x12\n\nvalue_hash\x18\x03 \x01(\x0c\"R\n\x13KVMetadataWriteHash\x12\x10\n\x08key_hash\x18\x01 \x01(\x0c\x12)\n\x07\x65ntries\x18\x02 \x03(\x0b\x32\x18.kvrwset.KVMetadataEntry\".\n\x0fKVMetadataEntry\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c\",\n\x07Version\x12\x11\n\tblock_num\x18\x01 \x01(\x04\x12\x0e\n\x06tx_num\x18\x02 \x01(\x04\"\xc4\x01\n\x0eRangeQueryInfo\x12\x11\n\tstart_key\x18\x01 \x01(\t\x12\x0f\n\x07\x65nd_key\x18\x02 \x01(\t\x12\x15\n\ritr_exhausted\x18\x03 \x01(\x08\x12(\n\traw_reads\x18\x04 \x01(\x0b\x32\x13.kvrwset.QueryReadsH\x00\x12?\n\x13reads_merkle_hashes\x18\x05 \x01(\x0b\x32 .kvrwset.QueryReadsMerkleSummaryH\x00\x42\x0c\n\nreads_info\"/\n\nQueryReads\x12!\n\x08kv_reads\x18\x01 \x03(\x0b\x32\x0f.kvrwset.KVRead\"Z\n\x17QueryReadsMerkleSummary\x12\x12\n\nmax_degree\x18\x01 \x01(\r\x12\x11\n\tmax_level\x18\x02 \x01(\r\x12\x18\n\x10max_level_hashes\x18\x03 \x03(\x0c\x42r\n2org.hyperledger.fabric.protos.ledger.rwset.kvrwsetZ<github.com/hyperledger/fabric-protos-go/ledger/rwset/kvrwsetb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ledger.rwset.kvrwset.kv_rwset_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n2org.hyperledger.fabric.protos.ledger.rwset.kvrwsetZ<github.com/hyperledger/fabric-protos-go/ledger/rwset/kvrwset'
  _KVRWSET._serialized_start=49
  _KVRWSET._serialized_end=228
  _HASHEDRWSET._serialized_start=231
  _HASHEDRWSET._serialized_end=387
  _KVREAD._serialized_start=389
  _KVREAD._serialized_end=445
  _KVWRITE._serialized_start=447
  _KVWRITE._serialized_end=503
  _KVMETADATAWRITE._serialized_start=505
  _KVMETADATAWRITE._serialized_end=578
  _KVREADHASH._serialized_start=580
  _KVREADHASH._serialized_end=645
  _KVWRITEHASH._serialized_start=647
  _KVWRITEHASH._serialized_end=717
  _KVMETADATAWRITEHASH._serialized_start=719
  _KVMETADATAWRITEHASH._serialized_end=801
  _KVMETADATAENTRY._serialized_start=803
  _KVMETADATAENTRY._serialized_end=849
  _VERSION._serialized_start=851
  _VERSION._serialized_end=895
  _RANGEQUERYINFO._serialized_start=898
  _RANGEQUERYINFO._serialized_end=1094
  _QUERYREADS._serialized_start=1096
  _QUERYREADS._serialized_end=1143
  _QUERYREADSMERKLESUMMARY._serialized_start=1145
  _QUERYREADSMERKLESUMMARY._serialized_end=1235
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from fabric_protos_python.gossip import message_pb2 as gossip_dot_message__pb2


class GossipStub(object):
    """Gossip
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GossipStream = channel.stream_stream(
                '/gossip.Gossip/GossipStream',
                request_serializer=gossip_dot_message__pb2.Envelope.SerializeToString,
                response_deserializer=gossip_dot_message__pb2.Envelope.FromString,
                )
        self.Ping = channel.unary_unary(
                '/gossip.Gossip/Ping',
                request_serializer=gossip_dot_message__pb2.Empty.SerializeToString,
                response_deserializer=gossip_dot_message__pb2.Empty.FromString,
                )


class GossipServicer(object):
    """Gossip
    """

    def GossipStream(self, request_iterator, context):
        """GossipStream is the gRPC stream used for sending and receiving messages
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Ping(self, request, context):
        """Ping is used to probe a remote peer's aliveness
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_GossipServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GossipStream': grpc.stream_stream_rpc_method_handler(
                    servicer.GossipStream,
                    request_deserializer=gossip_dot_message__pb2.Envelope.FromString,
                    response_serializer=gossip_dot_message__pb2.Envelope.SerializeToString,
            ),
            'Ping': grpc.unary_unary_rpc_method_handler(
                    servicer.Ping,
                    request_deserializer=gossip_dot_message__pb2.Empty.FromString,
                    response_serializer=gossip_dot_message__pb2.Empty.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'gossip.Gossip', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Gossip(object):
    """Gossip
    """

    @staticmethod
    def GossipStream(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_stream(request_iterator, target, '/gossip.Gossip/GossipStream',
            gossip_dot_message__pb2.Envelope.SerializeToString,
            gossip_dot_message__pb2.Envelope.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Ping(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/gossip.Gossip/Ping',
            gossip_dot_message__pb2.Empty.SerializeToString,
            gossip_dot_message__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: peer/configuration.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18peer/configuration.proto\x12\x06protos\"7\n\x0b\x41nchorPeers\x12(\n\x0c\x61nchor_peers\x18\x01 \x03(\x0b\x32\x12.protos.AnchorPeer\"(\n\nAnchorPeer\x12\x0c\n\x04host\x18\x01 \x01(\t\x12\x0c\n\x04port\x18\x02 \x01(\x05\"!\n\x0b\x41PIResource\x12\x12\n\npolicy_ref\x18\x01 \x01(\t\"n\n\x04\x41\x43Ls\x12$\n\x04\x61\x63ls\x18\x01 \x03(\x0b\x32\x16.protos.ACLs.AclsEntry\x1a@\n\tAclsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\"\n\x05value\x18\x02 \x01(\x0b\x32\x13.protos.APIResource:\x02\x38\x01\x42R\n\"org.hyperledger.fabric.protos.peerZ,github.com/hyperledger/fabric-protos-go/peerb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'peer.configuration_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\"org.hyperledger.fabric.protos.peerZ,github.com/hyperledger/fabric-protos-go/peer'
  _ACLS_ACLSENTRY._options = None
  _ACLS_ACLSENTRY._serialized_options = b'8\001'
  _ANCHORPEERS._serialized_start=36
  _ANCHORPEERS._serialized_end=91
  _ANCHORPEER._serialized_start=93
  _ANCHORPEER._serialized_end=133
  _APIRESOURCE._serialized_start=135
  _APIRESOURCE._serialized_end=168
  _ACLS._serialized_start=170
  _ACLS._serialized_end=280
  _ACLS_ACLSENTRY._serialized_start=216
  _ACLS_ACLSENTRY._serialized_end=280
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['fabric_protos_python',
 'fabric_protos_python.common',
 'fabric_protos_python.discovery',
 'fabric_protos_python.gateway',
 'fabric_protos_python.gossip',
 'fabric_protos_python.ledger',
 'fabric_protos_python.ledger.queryresult',
 'fabric_protos_python.ledger.rwset',
 'fabric_protos_python.ledger.rwset.kvrwset',
 'fabric_protos_python.msp',
 'fabric_protos_python.orderer',
 'fabric_protos_python.orderer.etcdraft',
 'fabric_protos_python.peer',
 'fabric_protos_python.peer.lifecycle',
 'fabric_protos_python.transientstore']

package_data = \
{'': ['*']}

install_requires = \
['grpclib>=0.4.3,<0.5.0', 'protobuf>=4.21.7,<5.0.0']

setup_kwargs = {
    'name': 'fabric-protos-python',
    'version': '2.4',
    'description': 'Hyperledger Fabric gRPC and Protocol Buffer Bindings for python',
    'long_description': '# fabric-protos-python\nHyperledger Fabric gRPC and Protocol Buffer Bindings for python\n\n## Community\n\nWe welcome contributions to the Hyperledger Fabric project in many forms.\nThere’s always plenty to do! Check the documentation on\n[how to contribute][contributing] to this project for the full details.\n\n- [Hyperledger Community](https://www.hyperledger.org/community)\n- [Hyperledger mailing lists and archives](http://lists.hyperledger.org/)\n- [Hyperledger Chat](http://chat.hyperledger.org/channel/fabric)\n- [Hyperledger Fabric Issue Tracking (JIRA)](https://jira.hyperledger.org/secure/Dashboard.jspa?selectPageId=10104)\n- [Hyperledger Fabric Wiki](https://wiki.hyperledger.org/display/Fabric)\n- [Hyperledger Wiki](https://wiki.hyperledger.org/)\n- [Hyperledger Code of Conduct](https://wiki.hyperledger.org/display/HYP/Hyperledger+Code+of+Conduct)\n\n## License <a name="license"></a>\n\nHyperledger Project source code files are made available under the Apache License, Version 2.0 (Apache-2.0), located in the [LICENSE](LICENSE) file. Hyperledger Project documentation files are made available under the Creative Commons Attribution 4.0 International License (CC-BY-4.0), available at http://creativecommons.org/licenses/by/4.0/.\n\n[contributing]: https://hyperledger-fabric.readthedocs.io/en/latest/CONTRIBUTING.html\n[go]: https://golang.org/\n[grpc]: https://grpc.io/docs/guides/\n[protobuf]: https://github.com/protocolbuffers/protobuf/\n[rocketchat-image]: https://open.rocket.chat/images/join-chat.svg\n[rocketchat-url]: https://chat.hyperledger.org/channel/fabric\n',
    'author': 'Institute of Cryptography of the Faculty of Mathematics and Computer Science at University of Havana',
    'author_email': 'kmilo.denis.glez@yandex.com',
    'maintainer': 'Kmilo Denis González',
    'maintainer_email': 'kmilo.denis.glez@yandex.com',
    'url': 'https://github.com/ic-matcom/fabric-protos-python',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.7,<4.0',
}


setup(**setup_kwargs)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: peer/chaincode_event.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1apeer/chaincode_event.proto\x12\x06protos\"Z\n\x0e\x43haincodeEvent\x12\x14\n\x0c\x63haincode_id\x18\x01 \x01(\t\x12\r\n\x05tx_id\x18\x02 \x01(\t\x12\x12\n\nevent_name\x18\x03 \x01(\t\x12\x0f\n\x07payload\x18\x04 \x01(\x0c\x42i\n\"org.hyperledger.fabric.protos.peerB\x15\x43haincodeEventPackageZ,github.com/hyperledger/fabric-protos-go/peerb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'peer.chaincode_event_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\"org.hyperledger.fabric.protos.peerB\025ChaincodeEventPackageZ,github.com/hyperledger/fabric-protos-go/peer'
  _CHAINCODEEVENT._serialized_start=38
  _CHAINCODEEVENT._serialized_end=128
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from fabric_protos_python.gateway import gateway_pb2 as gateway_dot_gateway__pb2


class GatewayStub(object):
    """The Gateway API for evaluating and submitting transactions via the gateway.
    Transaction evaluation (query) requires the invocation of the Evaluate service
    Transaction submission (ledger updates) is a two step process invoking Endorse
    followed by Submit. A third step, invoking CommitStatus, is required if the
    clients wish to wait for a Transaction to be committed.
    The proposal and transaction must be signed by the client before each step.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Endorse = channel.unary_unary(
                '/gateway.Gateway/Endorse',
                request_serializer=gateway_dot_gateway__pb2.EndorseRequest.SerializeToString,
                response_deserializer=gateway_dot_gateway__pb2.EndorseResponse.FromString,
                )
        self.Submit = channel.unary_unary(
                '/gateway.Gateway/Submit',
                request_serializer=gateway_dot_gateway__pb2.SubmitRequest.SerializeToString,
                response_deserializer=gateway_dot_gateway__pb2.SubmitResponse.FromString,
                )
        self.CommitStatus = channel.unary_unary(
                '/gateway.Gateway/CommitStatus',
                request_serializer=gateway_dot_gateway__pb2.SignedCommitStatusRequest.SerializeToString,
                response_deserializer=gateway_dot_gateway__pb2.CommitStatusResponse.FromString,
                )
        self.Evaluate = channel.unary_unary(
                '/gateway.Gateway/Evaluate',
                request_serializer=gateway_dot_gateway__pb2.EvaluateRequest.SerializeToString,
                response_deserializer=gateway_dot_gateway__pb2.EvaluateResponse.FromString,
                )
        self.ChaincodeEvents = channel.unary_stream(
                '/gateway.Gateway/ChaincodeEvents',
                request_serializer=gateway_dot_gateway__pb2.SignedChaincodeEventsRequest.SerializeToString,
                response_deserializer=gateway_dot_gateway__pb2.ChaincodeEventsResponse.FromString,
                )


class GatewayServicer(object):
    """The Gateway API for evaluating and submitting transactions via the gateway.
    Transaction evaluation (query) requires the invocation of the Evaluate service
    Transaction submission (ledger updates) is a two step process invoking Endorse
    followed by Submit. A third step, invoking CommitStatus, is required if the
    clients wish to wait for a Transaction to be committed.
    The proposal and transaction must be signed by the client before each step.
    """

    def Endorse(self, request, context):
        """The Endorse service passes a proposed transaction to the gateway in order to
        obtain sufficient endorsement.
        The gateway will determine the endorsement plan for the requested chaincode and
        forward to the appropriate peers for endorsement. It will return to the client a
        prepared transaction in the form of an Envelope message as defined
        in common/common.proto. The client must sign the contents of this envelope
        before invoking the Submit service.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Submit(self, request, context):
        """The Submit service will process the prepared transaction returned from Endorse service
        once it has been signed by the client. It will wait for the transaction to be submitted to the
        ordering service but the client must invoke the CommitStatus service to wait for the transaction
        to be committed.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CommitStatus(self, request, context):
        """The CommitStatus service will indicate whether a prepared transaction previously submitted to
        the Submit sevice has been committed. It will wait for the commit to occur if it hasn’t already
        committed.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Evaluate(self, request, context):
        """The Evaluate service passes a proposed transaction to the gateway in order to invoke the
        transaction function and return the result to the client. No ledger updates are made.
        The gateway will select an appropriate peer to query based on block height and load.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ChaincodeEvents(self, request, context):
        """The ChaincodeEvents service supplies a stream of responses, each containing all the events emitted by the
        requested chaincode for a specific block. The streamed responses are ordered by ascending block number. Responses
        are only returned for blocks that contain the requested events, while blocks not containing any of the requested
        events are skipped.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_GatewayServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Endorse': grpc.unary_unary_rpc_method_handler(
                    servicer.Endorse,
                    request_deserializer=gateway_dot_gateway__pb2.EndorseRequest.FromString,
                    response_serializer=gateway_dot_gateway__pb2.EndorseResponse.SerializeToString,
            ),
            'Submit': grpc.unary_unary_rpc_method_handler(
                    servicer.Submit,
                    request_deserializer=gateway_dot_gateway__pb2.SubmitRequest.FromString,
                    response_serializer=gateway_dot_gateway__pb2.SubmitResponse.SerializeToString,
            ),
            'CommitStatus': grpc.unary_unary_rpc_method_handler(
                    servicer.CommitStatus,
                    request_deserializer=gateway_dot_gateway__pb2.SignedCommitStatusRequest.FromString,
                    response_serializer=gateway_dot_gateway__pb2.CommitStatusResponse.SerializeToString,
            ),
            'Evaluate': grpc.unary_unary_rpc_method_handler(
                    servicer.Evaluate,
                    request_deserializer=gateway_dot_gateway__pb2.EvaluateRequest.FromString,
                    response_serializer=gateway_dot_gateway__pb2.EvaluateResponse.SerializeToString,
            ),
            'ChaincodeEvents': grpc.unary_stream_rpc_method_handler(
                    servicer.ChaincodeEvents,
                    request_deserializer=gateway_dot_gateway__pb2.SignedChaincodeEventsRequest.FromString,
                    response_serializer=gateway_dot_gateway__pb2.ChaincodeEventsResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'gateway.Gateway', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Gateway(object):
    """The Gateway API for evaluating and submitting transactions via the gateway.
    Transaction evaluation (query) requires the invocation of the Evaluate service
    Transaction submission (ledger updates) is a two step process invoking Endorse
    followed by Submit. A third step, invoking CommitStatus, is required if the
    clients wish to wait for a Transaction to be committed.
    The proposal and transaction must be signed by the client before each step.
    """

    @staticmethod
    def Endorse(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/gateway.Gateway/Endorse',
            gateway_dot_gateway__pb2.EndorseRequest.SerializeToString,
            gateway_dot_gateway__pb2.EndorseResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Submit(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/gateway.Gateway/Submit',
            gateway_dot_gateway__pb2.SubmitRequest.SerializeToString,
            gateway_dot_gateway__pb2.SubmitResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CommitStatus(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/gateway.Gateway/CommitStatus',
            gateway_dot_gateway__pb2.SignedCommitStatusRequest.SerializeToString,
            gateway_dot_gateway__pb2.CommitStatusResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Evaluate(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/gateway.Gateway/Evaluate',
            gateway_dot_gateway__pb2.EvaluateRequest.SerializeToString,
            gateway_dot_gateway__pb2.EvaluateResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ChaincodeEvents(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/gateway.Gateway/ChaincodeEvents',
            gateway_dot_gateway__pb2.SignedChaincodeEventsRequest.SerializeToString,
            gateway_dot_gateway__pb2.ChaincodeEventsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: peer/resources.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from fabric_protos_python.common import configtx_pb2 as common_dot_configtx__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x14peer/resources.proto\x12\x06protos\x1a\x15\x63ommon/configtx.proto\"4\n\x13\x43haincodeIdentifier\x12\x0c\n\x04hash\x18\x01 \x01(\x0c\x12\x0f\n\x07version\x18\x02 \x01(\t\"5\n\x13\x43haincodeValidation\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x10\n\x08\x61rgument\x18\x02 \x01(\x0c\"*\n\x08VSCCArgs\x12\x1e\n\x16\x65ndorsement_policy_ref\x18\x01 \x01(\t\"$\n\x14\x43haincodeEndorsement\x12\x0c\n\x04name\x18\x01 \x01(\t\"^\n\nConfigTree\x12&\n\x0e\x63hannel_config\x18\x01 \x01(\x0b\x32\x0e.common.Config\x12(\n\x10resources_config\x18\x02 \x01(\x0b\x32\x0e.common.ConfigBR\n\"org.hyperledger.fabric.protos.peerZ,github.com/hyperledger/fabric-protos-go/peerb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'peer.resources_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\"org.hyperledger.fabric.protos.peerZ,github.com/hyperledger/fabric-protos-go/peer'
  _CHAINCODEIDENTIFIER._serialized_start=55
  _CHAINCODEIDENTIFIER._serialized_end=107
  _CHAINCODEVALIDATION._serialized_start=109
  _CHAINCODEVALIDATION._serialized_end=162
  _VSCCARGS._serialized_start=164
  _VSCCARGS._serialized_end=206
  _CHAINCODEENDORSEMENT._serialized_start=208
  _CHAINCODEENDORSEMENT._serialized_end=244
  _CONFIGTREE._serialized_start=246
  _CONFIGTREE._serialized_end=340
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gossip/message.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from fabric_protos_python.peer import collection_pb2 as peer_dot_collection__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x14gossip/message.proto\x12\x06gossip\x1a\x15peer/collection.proto\"_\n\x08\x45nvelope\x12\x0f\n\x07payload\x18\x01 \x01(\x0c\x12\x11\n\tsignature\x18\x02 \x01(\x0c\x12/\n\x0fsecret_envelope\x18\x03 \x01(\x0b\x32\x16.gossip.SecretEnvelope\"4\n\x0eSecretEnvelope\x12\x0f\n\x07payload\x18\x01 \x01(\x0c\x12\x11\n\tsignature\x18\x02 \x01(\x0c\"/\n\x06Secret\x12\x1a\n\x10internalEndpoint\x18\x01 \x01(\tH\x00\x42\t\n\x07\x63ontent\"\x8d\t\n\rGossipMessage\x12\r\n\x05nonce\x18\x01 \x01(\x04\x12\x0f\n\x07\x63hannel\x18\x02 \x01(\x0c\x12&\n\x03tag\x18\x03 \x01(\x0e\x32\x19.gossip.GossipMessage.Tag\x12)\n\talive_msg\x18\x05 \x01(\x0b\x32\x14.gossip.AliveMessageH\x00\x12,\n\x07mem_req\x18\x06 \x01(\x0b\x32\x19.gossip.MembershipRequestH\x00\x12-\n\x07mem_res\x18\x07 \x01(\x0b\x32\x1a.gossip.MembershipResponseH\x00\x12\'\n\x08\x64\x61ta_msg\x18\x08 \x01(\x0b\x32\x13.gossip.DataMessageH\x00\x12$\n\x05hello\x18\t \x01(\x0b\x32\x13.gossip.GossipHelloH\x00\x12&\n\x08\x64\x61ta_dig\x18\n \x01(\x0b\x32\x12.gossip.DataDigestH\x00\x12\'\n\x08\x64\x61ta_req\x18\x0b \x01(\x0b\x32\x13.gossip.DataRequestH\x00\x12)\n\x0b\x64\x61ta_update\x18\x0c \x01(\x0b\x32\x12.gossip.DataUpdateH\x00\x12\x1e\n\x05\x65mpty\x18\r \x01(\x0b\x32\r.gossip.EmptyH\x00\x12%\n\x04\x63onn\x18\x0e \x01(\x0b\x32\x15.gossip.ConnEstablishH\x00\x12\'\n\nstate_info\x18\x0f \x01(\x0b\x32\x11.gossip.StateInfoH\x00\x12\x33\n\x0estate_snapshot\x18\x10 \x01(\x0b\x32\x19.gossip.StateInfoSnapshotH\x00\x12;\n\x13state_info_pull_req\x18\x11 \x01(\x0b\x32\x1c.gossip.StateInfoPullRequestH\x00\x12\x33\n\rstate_request\x18\x12 \x01(\x0b\x32\x1a.gossip.RemoteStateRequestH\x00\x12\x35\n\x0estate_response\x18\x13 \x01(\x0b\x32\x1b.gossip.RemoteStateResponseH\x00\x12\x33\n\x0eleadership_msg\x18\x14 \x01(\x0b\x32\x19.gossip.LeadershipMessageH\x00\x12-\n\rpeer_identity\x18\x15 \x01(\x0b\x32\x14.gossip.PeerIdentityH\x00\x12&\n\x03\x61\x63k\x18\x16 \x01(\x0b\x32\x17.gossip.AcknowledgementH\x00\x12\x32\n\nprivateReq\x18\x17 \x01(\x0b\x32\x1c.gossip.RemotePvtDataRequestH\x00\x12\x33\n\nprivateRes\x18\x18 \x01(\x0b\x32\x1d.gossip.RemotePvtDataResponseH\x00\x12\x32\n\x0cprivate_data\x18\x19 \x01(\x0b\x32\x1a.gossip.PrivateDataMessageH\x00\"_\n\x03Tag\x12\r\n\tUNDEFINED\x10\x00\x12\t\n\x05\x45MPTY\x10\x01\x12\x0c\n\x08ORG_ONLY\x10\x02\x12\r\n\tCHAN_ONLY\x10\x03\x12\x10\n\x0c\x43HAN_AND_ORG\x10\x04\x12\x0f\n\x0b\x43HAN_OR_ORG\x10\x05\x42\t\n\x07\x63ontent\"}\n\tStateInfo\x12#\n\ttimestamp\x18\x02 \x01(\x0b\x32\x10.gossip.PeerTime\x12\x0e\n\x06pki_id\x18\x03 \x01(\x0c\x12\x13\n\x0b\x63hannel_MAC\x18\x04 \x01(\x0c\x12&\n\nproperties\x18\x05 \x01(\x0b\x32\x12.gossip.Properties\"`\n\nProperties\x12\x15\n\rledger_height\x18\x01 \x01(\x04\x12\x14\n\x0cleft_channel\x18\x02 \x01(\x08\x12%\n\nchaincodes\x18\x03 \x03(\x0b\x32\x11.gossip.Chaincode\"7\n\x11StateInfoSnapshot\x12\"\n\x08\x65lements\x18\x01 \x03(\x0b\x32\x10.gossip.Envelope\"+\n\x14StateInfoPullRequest\x12\x13\n\x0b\x63hannel_MAC\x18\x01 \x01(\x0c\"W\n\rConnEstablish\x12\x0e\n\x06pki_id\x18\x01 \x01(\x0c\x12\x10\n\x08identity\x18\x02 \x01(\x0c\x12\x15\n\rtls_cert_hash\x18\x03 \x01(\x0c\x12\r\n\x05probe\x18\x04 \x01(\x08\">\n\x0cPeerIdentity\x12\x0e\n\x06pki_id\x18\x01 \x01(\x0c\x12\x0c\n\x04\x63\x65rt\x18\x02 \x01(\x0c\x12\x10\n\x08metadata\x18\x03 \x01(\x0c\"T\n\x0b\x44\x61taRequest\x12\r\n\x05nonce\x18\x01 \x01(\x04\x12\x0f\n\x07\x64igests\x18\x02 \x03(\x0c\x12%\n\x08msg_type\x18\x03 \x01(\x0e\x32\x13.gossip.PullMsgType\"U\n\x0bGossipHello\x12\r\n\x05nonce\x18\x01 \x01(\x04\x12\x10\n\x08metadata\x18\x02 \x01(\x0c\x12%\n\x08msg_type\x18\x03 \x01(\x0e\x32\x13.gossip.PullMsgType\"b\n\nDataUpdate\x12\r\n\x05nonce\x18\x01 \x01(\x04\x12\x1e\n\x04\x64\x61ta\x18\x02 \x03(\x0b\x32\x10.gossip.Envelope\x12%\n\x08msg_type\x18\x03 \x01(\x0e\x32\x13.gossip.PullMsgType\"S\n\nDataDigest\x12\r\n\x05nonce\x18\x01 \x01(\x04\x12\x0f\n\x07\x64igests\x18\x02 \x03(\x0c\x12%\n\x08msg_type\x18\x03 \x01(\x0e\x32\x13.gossip.PullMsgType\"/\n\x0b\x44\x61taMessage\x12 \n\x07payload\x18\x01 \x01(\x0b\x32\x0f.gossip.Payload\"=\n\x12PrivateDataMessage\x12\'\n\x07payload\x18\x01 \x01(\x0b\x32\x16.gossip.PrivatePayload\">\n\x07Payload\x12\x0f\n\x07seq_num\x18\x01 \x01(\x04\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\x0c\x12\x14\n\x0cprivate_data\x18\x03 \x03(\x0c\"\xbb\x01\n\x0ePrivatePayload\x12\x17\n\x0f\x63ollection_name\x18\x01 \x01(\t\x12\x11\n\tnamespace\x18\x02 \x01(\t\x12\r\n\x05tx_id\x18\x03 \x01(\t\x12\x15\n\rprivate_rwset\x18\x04 \x01(\x0c\x12\x1a\n\x12private_sim_height\x18\x05 \x01(\x04\x12;\n\x12\x63ollection_configs\x18\x06 \x01(\x0b\x32\x1f.protos.CollectionConfigPackage\"i\n\x0c\x41liveMessage\x12\"\n\nmembership\x18\x01 \x01(\x0b\x32\x0e.gossip.Member\x12#\n\ttimestamp\x18\x02 \x01(\x0b\x32\x10.gossip.PeerTime\x12\x10\n\x08identity\x18\x04 \x01(\x0c\"`\n\x11LeadershipMessage\x12\x0e\n\x06pki_id\x18\x01 \x01(\x0c\x12#\n\ttimestamp\x18\x02 \x01(\x0b\x32\x10.gossip.PeerTime\x12\x16\n\x0eis_declaration\x18\x03 \x01(\x08\",\n\x08PeerTime\x12\x0f\n\x07inc_num\x18\x01 \x01(\x04\x12\x0f\n\x07seq_num\x18\x02 \x01(\x04\"N\n\x11MembershipRequest\x12*\n\x10self_information\x18\x01 \x01(\x0b\x32\x10.gossip.Envelope\x12\r\n\x05known\x18\x02 \x03(\x0c\"U\n\x12MembershipResponse\x12\x1f\n\x05\x61live\x18\x01 \x03(\x0b\x32\x10.gossip.Envelope\x12\x1e\n\x04\x64\x65\x61\x64\x18\x02 \x03(\x0b\x32\x10.gossip.Envelope\"<\n\x06Member\x12\x10\n\x08\x65ndpoint\x18\x01 \x01(\t\x12\x10\n\x08metadata\x18\x02 \x01(\x0c\x12\x0e\n\x06pki_id\x18\x03 \x01(\x0c\"\x07\n\x05\x45mpty\"@\n\x12RemoteStateRequest\x12\x15\n\rstart_seq_num\x18\x01 \x01(\x04\x12\x13\n\x0b\x65nd_seq_num\x18\x02 \x01(\x04\"8\n\x13RemoteStateResponse\x12!\n\x08payloads\x18\x01 \x03(\x0b\x32\x0f.gossip.Payload\">\n\x14RemotePvtDataRequest\x12&\n\x07\x64igests\x18\x01 \x03(\x0b\x32\x15.gossip.PvtDataDigest\"n\n\rPvtDataDigest\x12\r\n\x05tx_id\x18\x01 \x01(\t\x12\x11\n\tnamespace\x18\x02 \x01(\t\x12\x12\n\ncollection\x18\x03 \x01(\t\x12\x11\n\tblock_seq\x18\x04 \x01(\x04\x12\x14\n\x0cseq_in_block\x18\x05 \x01(\x04\"A\n\x15RemotePvtDataResponse\x12(\n\x08\x65lements\x18\x01 \x03(\x0b\x32\x16.gossip.PvtDataElement\"H\n\x0ePvtDataElement\x12%\n\x06\x64igest\x18\x01 \x01(\x0b\x32\x15.gossip.PvtDataDigest\x12\x0f\n\x07payload\x18\x02 \x03(\x0c\":\n\x0ePvtDataPayload\x12\x17\n\x0ftx_seq_in_block\x18\x01 \x01(\x04\x12\x0f\n\x07payload\x18\x02 \x01(\x0c\" \n\x0f\x41\x63knowledgement\x12\r\n\x05\x65rror\x18\x01 \x01(\t\"<\n\tChaincode\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\x12\x10\n\x08metadata\x18\x03 \x01(\x0c*=\n\x0bPullMsgType\x12\r\n\tUNDEFINED\x10\x00\x12\r\n\tBLOCK_MSG\x10\x01\x12\x10\n\x0cIDENTITY_MSG\x10\x02\x32\x66\n\x06Gossip\x12\x36\n\x0cGossipStream\x12\x10.gossip.Envelope\x1a\x10.gossip.Envelope(\x01\x30\x01\x12$\n\x04Ping\x12\r.gossip.Empty\x1a\r.gossip.EmptyBV\n$org.hyperledger.fabric.protos.gossipZ.github.com/hyperledger/fabric-protos-go/gossipb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gossip.message_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n$org.hyperledger.fabric.protos.gossipZ.github.com/hyperledger/fabric-protos-go/gossip'
  _PULLMSGTYPE._serialized_start=3713
  _PULLMSGTYPE._serialized_end=3774
  _ENVELOPE._serialized_start=55
  _ENVELOPE._serialized_end=150
  _SECRETENVELOPE._serialized_start=152
  _SECRETENVELOPE._serialized_end=204
  _SECRET._serialized_start=206
  _SECRET._serialized_end=253
  _GOSSIPMESSAGE._serialized_start=256
  _GOSSIPMESSAGE._serialized_end=1421
  _GOSSIPMESSAGE_TAG._serialized_start=1315
  _GOSSIPMESSAGE_TAG._serialized_end=1410
  _STATEINFO._serialized_start=1423
  _STATEINFO._serialized_end=1548
  _PROPERTIES._serialized_start=1550
  _PROPERTIES._serialized_end=1646
  _STATEINFOSNAPSHOT._serialized_start=1648
  _STATEINFOSNAPSHOT._serialized_end=1703
  _STATEINFOPULLREQUEST._serialized_start=1705
  _STATEINFOPULLREQUEST._serialized_end=1748
  _CONNESTABLISH._serialized_start=1750
  _CONNESTABLISH._serialized_end=1837
  _PEERIDENTITY._serialized_start=1839
  _PEERIDENTITY._serialized_end=1901
  _DATAREQUEST._serialized_start=1903
  _DATAREQUEST._serialized_end=1987
  _GOSSIPHELLO._serialized_start=1989
  _GOSSIPHELLO._serialized_end=2074
  _DATAUPDATE._serialized_start=2076
  _DATAUPDATE._serialized_end=2174
  _DATADIGEST._serialized_start=2176
  _DATADIGEST._serialized_end=2259
  _DATAMESSAGE._serialized_start=2261
  _DATAMESSAGE._serialized_end=2308
  _PRIVATEDATAMESSAGE._serialized_start=2310
  _PRIVATEDATAMESSAGE._serialized_end=2371
  _PAYLOAD._serialized_start=2373
  _PAYLOAD._serialized_end=2435
  _PRIVATEPAYLOAD._serialized_start=2438
  _PRIVATEPAYLOAD._serialized_end=2625
  _ALIVEMESSAGE._serialized_start=2627
  _ALIVEMESSAGE._serialized_end=2732
  _LEADERSHIPMESSAGE._serialized_start=2734
  _LEADERSHIPMESSAGE._serialized_end=2830
  _PEERTIME._serialized_start=2832
  _PEERTIME._serialized_end=2876
  _MEMBERSHIPREQUEST._serialized_start=2878
  _MEMBERSHIPREQUEST._serialized_end=2956
  _MEMBERSHIPRESPONSE._serialized_start=2958
  _MEMBERSHIPRESPONSE._serialized_end=3043
  _MEMBER._serialized_start=3045
  _MEMBER._serialized_end=3105
  _EMPTY._serialized_start=3107
  _EMPTY._serialized_end=3114
  _REMOTESTATEREQUEST._serialized_start=3116
  _REMOTESTATEREQUEST._serialized_end=3180
  _REMOTESTATERESPONSE._serialized_start=3182
  _REMOTESTATERESPONSE._serialized_end=3238
  _REMOTEPVTDATAREQUEST._serialized_start=3240
  _REMOTEPVTDATAREQUEST._serialized_end=3302
  _PVTDATADIGEST._serialized_start=3304
  _PVTDATADIGEST._serialized_end=3414
  _REMOTEPVTDATARESPONSE._serialized_start=3416
  _REMOTEPVTDATARESPONSE._serialized_end=3481
  _PVTDATAELEMENT._serialized_start=3483
  _PVTDATAELEMENT._serialized_end=3555
  _PVTDATAPAYLOAD._serialized_start=3557
  _PVTDATAPAYLOAD._serialized_end=3615
  _ACKNOWLEDGEMENT._serialized_start=3617
  _ACKNOWLEDGEMENT._serialized_end=3649
  _CHAINCODE._serialized_start=3651
  _CHAINCODE._serialized_end=3711
  _GOSSIP._serialized_start=3776
  _GOSSIP._serialized_end=3878
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: orderer/cluster.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from fabric_protos_python.common import common_pb2 as common_dot_common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15orderer/cluster.proto\x12\x07orderer\x1a\x13\x63ommon/common.proto\"\x82\x01\n\x0bStepRequest\x12\x36\n\x11\x63onsensus_request\x18\x01 \x01(\x0b\x32\x19.orderer.ConsensusRequestH\x00\x12\x30\n\x0esubmit_request\x18\x02 \x01(\x0b\x32\x16.orderer.SubmitRequestH\x00\x42\t\n\x07payload\"H\n\x0cStepResponse\x12-\n\nsubmit_res\x18\x01 \x01(\x0b\x32\x17.orderer.SubmitResponseH\x00\x42\t\n\x07payload\"F\n\x10\x43onsensusRequest\x12\x0f\n\x07\x63hannel\x18\x01 \x01(\t\x12\x0f\n\x07payload\x18\x02 \x01(\x0c\x12\x10\n\x08metadata\x18\x03 \x01(\x0c\"`\n\rSubmitRequest\x12\x0f\n\x07\x63hannel\x18\x01 \x01(\t\x12\x1b\n\x13last_validation_seq\x18\x02 \x01(\x04\x12!\n\x07payload\x18\x03 \x01(\x0b\x32\x10.common.Envelope\"O\n\x0eSubmitResponse\x12\x0f\n\x07\x63hannel\x18\x01 \x01(\t\x12\x1e\n\x06status\x18\x02 \x01(\x0e\x32\x0e.common.Status\x12\x0c\n\x04info\x18\x03 \x01(\t2B\n\x07\x43luster\x12\x37\n\x04Step\x12\x14.orderer.StepRequest\x1a\x15.orderer.StepResponse(\x01\x30\x01\x42X\n%org.hyperledger.fabric.protos.ordererZ/github.com/hyperledger/fabric-protos-go/ordererb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'orderer.cluster_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n%org.hyperledger.fabric.protos.ordererZ/github.com/hyperledger/fabric-protos-go/orderer'
  _STEPREQUEST._serialized_start=56
  _STEPREQUEST._serialized_end=186
  _STEPRESPONSE._serialized_start=188
  _STEPRESPONSE._serialized_end=260
  _CONSENSUSREQUEST._serialized_start=262
  _CONSENSUSREQUEST._serialized_end=332
  _SUBMITREQUEST._serialized_start=334
  _SUBMITREQUEST._serialized_end=430
  _SUBMITRESPONSE._serialized_start=432
  _SUBMITRESPONSE._serialized_end=511
  _CLUSTER._serialized_start=513
  _CLUSTER._serialized_end=579
# @@protoc_insertion_point(module_scope)
